<?php


namespace FiloBlu\PaymentMethodFilter\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Store\Model\ScopeInterface;
use FiloBlu\PaymentMethodFilter\Model\Serializer;
use Magento\Framework\App\ObjectManager;

class PaymentFilter extends AbstractHelper
{

    const FILTER_ENABLE_CONFIG_PATH = 'payment_method_filter/default/enable';
    const WHITELISTED_METHODS_CONFIG_PATH = 'payment_method_filter/default/whitelist_payment_methods';
    const FILTER_CONDITION_CONFIG_PATH = 'payment_method_filter/default/filter_condition';
    const PREVENT_BUY_GIFTCARD_WITH_GIFTCARD_CONFIG_PATH = 'payment_method_filter/gift_cards/prevent_paying_giftcards_with_giftcards';

    private $serializer;

    /**
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        Serializer $serializer = null

    ) {
        parent::__construct($context);
        $this->serializer = $serializer ?: ObjectManager::getInstance()->get(Serializer::class);
    }

    public function isFilterEnabled() {
        return $this->scopeConfig->isSetFlag(self::FILTER_ENABLE_CONFIG_PATH, ScopeInterface::SCOPE_WEBSITE);
    }

    public function paymentMethodWhitelist() {
        $list = [];
        if ($this->scopeConfig->getValue(self::WHITELISTED_METHODS_CONFIG_PATH, ScopeInterface::SCOPE_WEBSITE) != '') {
            $list = explode(',', $this->scopeConfig->getValue(self::WHITELISTED_METHODS_CONFIG_PATH, ScopeInterface::SCOPE_WEBSITE));
        }
        return $list;
    }

    public function quoteContainsGiftcard($quote) {
        if (is_null($quote) == FALSE) {
            foreach ($quote->getAllItems() as $item) {
                if ($item->getProductType() == 'giftcard') {
                    return TRUE;
                }
            }
        }
        return FALSE;
    }

    public function getFilterconditions() {
        $conditions = [];
        $filterCondition = $this->scopeConfig->getValue(self::FILTER_CONDITION_CONFIG_PATH, ScopeInterface::SCOPE_WEBSITE);
        if (!is_null($filterCondition)) {
            $conditions = explode(',', $filterCondition);
        }
        return $conditions;
    }

    public function isGiftcardBuyingPrevented() {
        return $this->scopeConfig->isSetFlag(self::PREVENT_BUY_GIFTCARD_WITH_GIFTCARD_CONFIG_PATH, ScopeInterface::SCOPE_WEBSITE);
    }

    /** @var \Magento\Quote\Model\Quote $quote */
    public function isPayingWithGiftcard($quote) {
        $giftcards = $quote->getGiftCards();
        if (is_null($giftcards)) {
            return FALSE;
        }
        return count($this->serializer->unserialize($giftcards)) > 0;
    }
}